embrace library

Classes

Embrace
Entry point for the SDK. This class is part of the Embrace Public API.
EmbraceHttpClient
A Client that automatically logs http requests to Embrace.
EmbraceNavigationObserver
A NavigatorObserver that automatically tracks app navigation This class registers in Embrace when a view starts or stops by listening when a route is pushed or popped.
EmbraceSpanImpl
Implementation detail of EmbraceSpan. You should not use this directly as function signatures may change without warning.

Enums

HttpMethod
Used to represent an HTTP method when logging network requests

Properties

debugEmbraceOverride Embrace?
A variable that can be used to override Embrace.instance for mocking in unit tests. If set to a non-null value, Embrace.instance will return this instead of its default behavior.
getter/setter pair

Typedefs

EmbraceRouteSettingsExtractor = RouteSettings? Function(Route route)
A function that extracts the settings from a route