embrace_api library
Classes
- EmbraceApi
- Declares the functions that consist of Embrace's public API. You should not use EmbraceApi directly or implement it in your own custom classes, as new functions may be added in future. Use the Embrace class instead.
- EmbraceFlutterApi
- Declares the functions that consist of Embrace's public API - specifically those that are only declared on Flutter. You should not use EmbraceFlutterApi directly or implement it in your own custom classes, as new functions may be added in future. Use the Embrace class instead.
- EmbraceNetworkRequest
- This class is used to create manually-recorded network requests.
- LogsApi
- Declares the functions that consist of Embrace's public API. You should not use LogsApi directly or implement it in your own custom classes, as new functions may be added in future. Use the Embrace class instead.
- MomentsApi
- Declares the functions that consist of Embrace's public API. You should not use MomentsApi directly or implement it in your own custom classes, as new functions may be added in future. Use the Embrace class instead.
- NetworkRequestApi
- Declares the functions that consist of Embrace's public API. You should not use NetworkRequestApi directly or implement it in your own custom classes, as new functions may be added in future. Use the Embrace class instead.
- SessionApi
- Declares the functions that consist of Embrace's public API. You should not use SessionApi directly or implement it in your own custom classes, as new functions may be added in future. Use the Embrace class instead.
- UserApi
- Declares the functions that consist of Embrace's public API. You should not use UserApi directly or implement it in your own custom classes, as new functions may be added in future. Use the Embrace class instead.
Enums
- Severity
- The severity of the log message