start abstract method
Future<void>
start({
- FutureOr<
void> action()?, - @Deprecated('This parameter is obsolete and will be removed in a future release.') bool enableIntegrationTesting = false,
Starts instrumentation of Dart code by the Embrace SDK.
If action is provided and error handlers are not disabled, this will
wrap the action in a guarded zone to capture uncaught Dart errors. This
should wrap the entire contents of your Dart main() function if you wish
to capture Dart errors.
If action is not provided, you can call installErrorHandlers later
to set up error handling separately. This is useful for background
isolates or when you need more control over initialization order.
You must also call Embrace.instance.start as soon as possible in your Android and iOS native code.
Implementation
Future<void> start({
FutureOr<void> Function()? action,
@Deprecated(
'This parameter is obsolete and will be removed in a future release.',
)
bool enableIntegrationTesting = false,
});