EmbraceSpanEvent class

Represents an Event in an EmbraceSpan

Constructors

EmbraceSpanEvent({required String name, required int timestampMs, required Map<String, String> attributes})
Constructor

Properties

attributes → Map<String, String>
The attributes of this event
final
hashCode → int
The hash code for this object.
no setterinherited
name → String
The name of the event
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
timestampMs → int
The timestamp of the event in milliseconds
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
Produces a map representation of this class
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited